<?php
/**
Plugin Name: Show Only Selected When Logged Out 
Plugin URI: https://fischercreatvemedia.com/custom-plugins/
Description: Custom Plugin for showing only certain pages when logged out. Can also be used to redirect to a specific page when logged out for any page that is not set as ok to show.
Version: 1.4.2
Author: Don Fischer - Fischer Creative Media, LLC.
Author URI: https://fischercreativemedia.com/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html

 * Copyright (C)2021 Donald J Fischer
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the [GNU General Public License](http://wordpress.org/about/gpl/)
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * on an "AS IS", but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see [GNU General Public Licenses](http://www.gnu.org/licenses/),
 * or write to the Free Software Foundation, Inc., 51 Franklin Street,
 * Fifth Floor, Boston, MA 02110-1301, USA.
*/
//Because this is not on the Repository, we need a way to update it if changed.
require_once( plugin_dir_path( __FILE__ ).'/updates/plugin-update-checker.php' );
new FCMPluginUpdateChecker_1_7 ( 'https://graphiccaffeine.com/wp-admin/admin-ajax.php', __FILE__ );

add_filter( 'all_plugins', function ( $plugins ) {
  if ( isset( $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ] ) ) {
    $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ][ 'update-supported' ] = true;
    $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ][ 'id' ] = 'gc.com/plugins/show-page-when-logged-out';
    $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ][ 'slug' ] = 'show-page-when-logged-out';
    $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ][ 'plugin' ] = 'show-page-when-logged-out/show-page-when-logged-out.php';
    $plugins[ 'show-page-when-logged-out/show-page-when-logged-out.php' ][ 'url' ] = 'https://graphiccaffeine.com/fcm-custom-plugins/show-page-when-logged-out/';
  }
  return $plugins;
}, 10);

class loginFeaturesShowPage {
	function __construct() {
		add_action( 'admin_init', array( $this, 'custom_theme_add_option' ) );
		add_action( 'template_redirect', array( $this, 'custom_theme_redirect' ) );
		add_action( 'init', array( $this, 'custom_theme_block_dashboard' ) );	
		add_filter( 'wp_get_nav_menu_items', array($this,'exclude_menu_items'), 100, 3 );
	}
	
	function exclude_menu_items( $items, $menu, $args ) {
		if(!is_user_logged_in()){
			foreach ( $items as $key => $item ) {
				if($item->post_name != 'home'){
					if($item->type == 'post_type'){
						$oktoload = ( get_post_meta( $item->object_id, '_ok-to-load-logged-out', true ) != '' ) ? true : false;
						if( !$oktoload ){
							unset( $items[$key] );
						}
					}else{
						unset( $items[$key] );
					}
				}
			}
		}
		return $items;
	}

	function custom_theme_redirect($content){
		if(!is_user_logged_in()){
			global $post;
			$redirecthome = get_option('logged-out-home-id', 0);
			$redirectpage = get_option('logged-out-url', '');
			if(is_front_page() || is_home() ){
				if($redirectpage != '' && $redirecthome == 0 ){
					//if Home Page set to --Select-- and URL not empty - then redirect the home page too
					wp_redirect( $redirectpage );
					exit();
				}elseif( $redirecthome != 0 ){
					if($post->ID == $redirecthome){
						$redirecthome = 0;
					}
					$homeurl = ($redirecthome == 0) ? home_url().'/' : get_permalink($redirecthome);
					wp_redirect( $homeurl );
					exit();
				}
			}else{
				$oktoload = ( get_post_meta( $post->ID, '_ok-to-load-logged-out', true ) != '' ) ? true : false;
				$oktoload = $oktoload == false && $post->ID == $redirecthome ? true : $oktoload;
				if(!$oktoload):
					if($redirectpage != '' && $redirecthome == 0 ){
						//if Home Page set to --Select-- and URL not empty
						wp_redirect( $redirectpage );
						exit();
					}else{
						if(!is_home() && !is_front_page() ){
							// dont want redirect loop for home page
							if($post->ID == $redirecthome){
								$redirecthome = 0;
							}
							$homeurl = ($redirecthome == 0) ? home_url().'/' : get_permalink($redirecthome);
							wp_redirect( $homeurl );
							exit();
						}
					}
				endif;
			}
		}
		return $content;
	}
	function custom_theme_add_option(){
		register_setting( 'reading', 'logged-out-role' );
		register_setting( 'reading', 'logged-out-home-id' );
		register_setting( 'reading', 'logged-out-url' );
		add_settings_field( 'logged-out-role', 'Logged In Admin Access Role', array($this, 'loggedout_role_callback_function' ), 'reading', 'default', array( 'label_for' => 'logged-out-role' ) );
		add_settings_field( 'logged-out-home-id', 'Logged Out Home Page', array($this, 'loggedout_home_callback_function' ), 'reading', 'default', array( 'label_for' => 'logged-out-home-id' ) );
		add_settings_field( 'logged-out-url', 'Logged Out Redirect URL', array($this, 'loggedout_url_callback_function' ), 'reading', 'default', array( 'label_for' => 'logged-out-url' ) );
	}
	function loggedout_home_callback_function(){
		echo wp_dropdown_pages( array( 'name' => 'logged-out-home-id', 'echo' => 0, 'show_option_none' => '&mdash; Select &mdash;', 'option_none_value' => '0', 'selected' => get_option( 'logged-out-home-id' ) ) );
		return;
	}
	function loggedout_url_callback_function(){
		echo '<input name="logged-out-url" value="'.get_option( 'logged-out-url' ).'" class="regular-text" type="text"><p class="description">If using an external URL, make sure Logged Out Home Page is set to "&mdash; Select &mdash;".</p>';
		return;
	}
	function loggedout_role_callback_function(){
		$rolesi = get_option( 'logged-out-role', "ALL" );
		echo '<select name="logged-out-role" value="'.get_option( 'logged-out-role' ).'" class="regular-text" type="text">
		<option value="ALL"'.($rolesi == "ALL" ? ' selected' : '').'>ALL</option>
		<option value="Admin"'.($rolesi == "Admin" ? ' selected' : '').'>Admin</option>
		<option value="Editor"'.($rolesi == "Editor" ? ' selected' : '').'>Editor</option>
		<option value="Contributor"'.($rolesi == "Contributer" ? ' selected' : '').'>Contributer</option>
		<option value="Author"'.($rolesi == "Author" ? ' selected' : '').'>Author</option>
		</select>
		<p class="description">Select the User Role that can access the Admin Menu When logged in. Any user that is below this role will NOT be able to access the Admin Menu. Select "All" if you want it at WordPress default.</p>';
		return;
	}
	function custom_theme_block_dashboard() {
		$file = basename($_SERVER['PHP_SELF']);
		$rolesi = get_option( 'logged-out-role', "ALL" );
		if($rolesi  == 'ALL'){
		}elseif($rolesi  == 'Admin'){
			if (is_user_logged_in() && is_admin() && !current_user_can('manage_options') && $file != 'admin-ajax.php'){
				wp_redirect( home_url() );
				exit();
			}			
		}elseif($rolesi  == 'Editor'){
			if (is_user_logged_in() && is_admin() && !current_user_can('edit_others_posts') && $file != 'admin-ajax.php'){
				wp_redirect( home_url() );
				exit();
			}
		}elseif($rolesi  == 'Contributer'){
			if (is_user_logged_in() && is_admin() && !current_user_can('edit_published_posts') && $file != 'admin-ajax.php'){
				wp_redirect( home_url() );
				exit();
			}
		}elseif($rolesi  == 'Author'){
			if (is_user_logged_in() && is_admin() && !current_user_can('edit_posts') && $file != 'admin-ajax.php'){
				wp_redirect( home_url() );
				exit();
			}
		}
	}
}

$custom_theme_login_features = new loginFeaturesShowPage();

function loginFeaturesShowPage_func() {  new loginFeaturesShowPageMeta();}

if ( is_admin() ) {
    add_action( 'load-post.php', 'loginFeaturesShowPage_func' );
    add_action( 'load-post-new.php', 'loginFeaturesShowPage_func' );
}

class loginFeaturesShowPageMeta {

	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ), 1 );
		add_action( 'save_post', array( $this, 'save' ) );
	}

	public function add_meta_box( $post_type ) {
		$post_types = apply_filters('show-logged-out_post-types', array('post', 'page') ); 
		if ( in_array( $post_type, $post_types )) {
			add_meta_box('show-logged-out','Show When Logged Out',array( $this, 'render_meta_box_content' ),$post_type,'side','high');
		}
	}

	public function save( $post_id ) {
		if ( ! isset( $_POST['show-logged_inner_custom_box_nonce'] ) ){
			return $post_id;
		}
		$nonce = $_POST['show-logged_inner_custom_box_nonce'];
		if ( ! wp_verify_nonce( $nonce, 'show-logged_inner_custom_box' ) ){
			return $post_id;
		}
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}
		if ( 'page' == $_POST['post_type'] ) {
			if ( ! current_user_can( 'edit_page', $post_id ) ){
				return $post_id;
			}
		} else {
			if ( ! current_user_can( 'edit_post', $post_id ) ){
				return $post_id;
			}
		}
		$mydata = sanitize_text_field( $_POST['show-logged_show_page'] );
		update_post_meta( $post_id, '_ok-to-load-logged-out', $mydata );
	}


	public function render_meta_box_content( $post ) {
		wp_nonce_field( 'show-logged_inner_custom_box', 'show-logged_inner_custom_box_nonce' );
		$value = get_post_meta( $post->ID, '_ok-to-load-logged-out', true );
		echo '<label for="show-logged_show_page">Show logged out?';
		if($value == '1'){
			echo '<input type="checkbox" id="show-logged_show_page" name="show-logged_show_page" value="1" checked="checked" style="float: right;margin-top: 5px;" />';
		}else{
			echo '<input type="checkbox" id="show-logged_show_page" name="show-logged_show_page" value="1" style="float: right;margin-top: 5px;" />';
		}
		echo '</label>';
	}
}